@@ -1,3 +1,7 @@
 from torch.optim.lr_scheduler import ReduceLROnPlateau as _ReduceLROnPlateau
 
 ReduceLROnPlateau = _ReduceLROnPlateau
+
+__all__ = [
+    "ReduceLROnPlateau"
+]
\ No newline at end of file
