@@ -59,3 +59,7 @@ def ifelse(predicate: Callable[[any], bool], func_true: Callable, func_false: Ca
             return func_false(*args, **kwargs)
 
     return wrapper
+
+
+def is_bad_num(x: Tensor) -> Tensor:
+    return torch.logical_or(torch.isnan(x), torch.isinf(x))
